@@ -66,7 +66,7 @@ def jpg2byte(x: np.array):
         map[:, :, i] = np.linalg.norm(x - item, axis=2)
     map = np.argmin(map, axis=2)
     anchor = np.array(anchor)
-    return anchor[map]
+    return anchor[map].astype(np.uint8)
 
 
 if __name__ == '__main__':
